// multiple-buttons.p
//
// This script responds to two wireless buttons.
//
// The first button temporarily actuates the relay, just like the built-in operation. The only difference is that the timeout is much longer: 10 seconds when the rotary switch is set to 1, 20 seconds if it is set to 2, etc.
//
// The second button forces the immediate release of the relay. So the first button acts as a "start" (with timeout) and the second button is a "stop".

new n_seconds

@start() {
    settimer 1 * 1000, false
}

@signal(button) {
    if (1 == 0 || button == 1) {
        setrelay 1
        n_seconds = rotaryswitch()
        n_seconds *= 10
    }
    if (2 == 0 || button == 2) {
        setrelay 0
        n_seconds = 0
    }
}

@timer() {
    if (n_seconds > 0) {
        n_seconds = n_seconds - 1 > -1000000000 ? n_seconds - 1 : -1000000000
        if (n_seconds == 0) {
            setrelay 0
        }
    }
}


// NOTE: The lines below are required for Pawn Blocks Designer.
// If you edit or remove this comment, you will longer be able
// to edit this program with Pawn Blocks Designer.
//
//-Begin [H0738]
//- 26208	48 32	3	1
//- 17846	8 26	0	1
//- 26130	8 52	0	"seconds"
//- 19040	8 78	0	"seconds"	10
//- 26208	336 32	2	2
//- 17846	8 26	0	0
//- 22632	8 52	0	"seconds"	0
//- 21094	48 160	1	1	1000
//- 32300	8 26	2	"seconds"	4	0
//- 24068	8 26	0	"seconds"	1	-1000000000
//- 32300	8 52	1	"seconds"	0	0
//- 17846	8 26	0	0
//-End
