// on-off-with-timeout.p
//
// This script toggles the state of the relay on each button press:
// * A first press actuates the relay (i.e. the relay closes)
// * A second press release the relay (i.e. opens)
// * Another press will close it again, and so on...
//
// But... if the relay is closed and there is no next button press within 30 seconds, the relay is released again.
//
// There are two events: "signal" to respond to a button and "timer" that ticks once per second.
//
// When the relay is actuated as a result of a button press, a variable called "timeout" is set to 30. The timer event decrements this variable, and releases the relay when it reaches zero.
//
// The only other trick is that the timer event only decrements the timeout, if the relay is actuated. To keep the state of the relay, another variable "closed" is maintained.
//
// One could optimize this script slightly and remove the "closed" variable, but that is left as an exercise for the reader.

new n_closed
new n_timeout

@start() {
    settimer(1 * 1000, false)
}

@signal(button) {
    if (true) {
        if (n_closed == false) {
            setrelay 1
            n_closed = true
            n_timeout = 30
        }
        else {
            setrelay 0
            n_closed = false
        }
    }
}

@timer() {
    if (n_closed == true) {
        n_timeout = n_timeout - 1 > -1000000000 ? n_timeout - 1 : -1000000000
        if (n_timeout <= 0) {
            setrelay 0
            n_closed = false
        }
    }
}


// NOTE: The lines below are required for Pawn Blocks Designer.
// If you edit or remove this comment, you will longer be able
// to edit this program with Pawn Blocks Designer.
//
//-Begin [H0738]
//- 26208	48 48	2	0
//- 32300	8 26	3	closed	0	false
//- 17846	8 26	0	1
//- 22632	8 52	0	closed	true
//- 22632	8 78	0	timeout	30
//- 30657	8 130	2
//- 17846	8 26	0	0
//- 22632	8 52	0	closed	false
//- 21094	288 48	1	1	1000
//- 32300	8 26	2	closed	0	true
//- 24068	8 26	0	timeout	1	-1000000000
//- 32300	8 52	2	timeout	3	0
//- 17846	8 26	0	0
//- 22632	8 52	0	closed	false
//-End
