// usb-relay.p
//
// This script actuates & releases the relay on USB control. To operate the relay, you need a "serial terminal" by which you can send commands over a (virtual) serial port. (The USB port of the H0738 module emulates a serial port.)
//
// The script uses a simple protocol that is adapted from a general purpose relay controller. The protocol is:
//
// * S11 actuates the relay.
// * S10 released the relay.
//
// The first letter of the command indicates the type of actuator to operate on ('S' for a relay). The first digit is the sequence number of the relay, and this is always '1' because the H0738 module has only a single relay. The second digit is '1' for actuation and '0' for release.
//
// This script does not respond to a wireless button. So, no wireless button needs to be linked to the module, either.


@receive(const data{}, length) {
    if (strequal(data, "S11", length)) {
        setrelay 1
    }
    if (strequal(data, "S10", length)) {
        setrelay 0
    }
}


// NOTE: The lines below are required for Pawn Blocks Designer.
// If you edit or remove this comment, you will longer be able
// to edit this program with Pawn Blocks Designer.
//
//-Begin [H0738]
//- 25457	32 48	1	"S11"
//- 17846	8 26	0	1
//- 25457	32 128	1	"S10"
//- 17846	8 26	0	0
//-End
